Schemas
=======

.. automodule:: pemi.schema
   :members:



Fields
------

.. currentmodule:: pemi.fields

.. autoclass:: Field
  :members:

.. autoclass:: StringField
  :members:

.. autoclass:: IntegerField
  :members:

.. autoclass:: FloatField
  :members:

.. autoclass:: DateField
  :members:

.. autoclass:: DateTimeField
  :members:

.. autoclass:: BooleanField
  :members:

.. autoclass:: DecimalField
  :members:

.. autoclass:: JsonField
  :members:
